@@ -1,5 +1,5 @@
 {-# LANGUAGE ScopedTypeVariables #-}
-module Test.Hspec.Core.HooksSpec (main, spec) where
+module Test.Hspec.Core.HooksSpec (spec) where
 
 import           Control.Exception
 import           Helper
@@ -10,9 +10,6 @@ import qualified Test.Hspec.Core.Spec as H
 
 import qualified Test.Hspec.Core.Hooks as H
 
-main :: IO ()
-main = hspec spec
-
 runSilent :: H.Spec -> IO ()
 runSilent = silence . H.hspec
 
@@ -34,10 +31,6 @@ spec = do
           rec (value ++ " bar")
       retrieve `shouldReturn` ["before", "value foo", "before", "value bar"]
 
-    context "when used multiple times" $ do
-      it "is evaluated outside in" $ do
-        pending
-
     context "when used with a QuickCheck property" $ do
       it "runs action before every check of the property" $ do
         (rec, retrieve) <- mkAppend
@@ -45,10 +38,6 @@ spec = do
           H.it "foo" $ \value -> property $ \(_ :: Int) -> rec value
         retrieve `shouldReturn` (take 200 . cycle) ["before", "value"]
 
-      context "when used multiple times" $ do
-        it "is evaluated outside in" $ do
-          pending
-
   describe "before_" $ do
     it "runs an action before every spec item" $ do
       (rec, retrieve) <- mkAppend
@@ -137,10 +126,6 @@ spec = do
           return ()
         retrieve `shouldReturn` []
 
-    context "when used multiple times" $ do
-      it "is evaluated outside in" $ do
-        pending
-
   describe "beforeAll_" $ do
     it "runs an action before the first spec item" $ do
       (rec, retrieve) <- mkAppend
@@ -195,10 +180,6 @@ spec = do
           rec "foo"
       retrieve `shouldReturn` ["before", "from before"]
 
-    context "when used multiple times" $ do
-      it "is evaluated inside out" $ do
-        pending
-
   describe "after_" $ do
     it "runs an action after every spec item" $ do
       (rec, retrieve) <- mkAppend
@@ -323,10 +304,6 @@ spec = do
         , "after"
         ]
 
-    context "when used multiple times" $ do
-      it "is evaluated outside in" $ do
-        pending
-
   describe "around_" $ do
     it "wraps every spec item with an action" $ do
       (rec, retrieve) <- mkAppend
